JunctureError

Struct JunctureError 

pub struct JunctureError { /* private fields */ }
Juncture error with backtrace

Implementations

Source

impl JunctureError

pub fn graph(msg: impl Into<String>) -> Self

Graph construction error

pub fn execution(msg: impl Into<String>) -> Self

Graph execution error

pub fn checkpoint(msg: impl Into<String>) -> Self

Checkpoint persistence error

pub fn interrupt(msg: impl Into<String>) -> Self

Human-in-the-loop interrupt

pub fn interrupted(index: usize) -> Self

Human-in-the-loop interrupted execution

pub fn subgraph(msg: impl Into<String>) -> Self

Subgraph error

pub fn invalid_update(msg: impl Into<String>) -> Self

Invalid state update

pub fn empty_channel() -> Self

Channel value is empty

pub fn empty_input() -> Self

Graph input is empty

pub fn task_not_found(id: impl Into<String>) -> Self

Task not found

pub fn timeout(msg: impl Into<String>) -> Self

Operation timed out

pub fn recursion_limit(step: usize, limit: usize) -> Self

Recursion limit exceeded

pub const fn backtrace(&self) -> &Backtrace

Access the backtrace for this error

pub const fn code(&self) -> ErrorCode

Get the error code categorizing this error

pub const fn is_graph(&self) -> bool

pub const fn is_execution(&self) -> bool

pub const fn is_checkpoint(&self) -> bool

pub const fn is_interrupt(&self) -> bool

pub const fn is_subgraph(&self) -> bool

pub const fn is_invalid_update(&self) -> bool

pub const fn is_empty_channel(&self) -> bool

pub const fn is_empty_input(&self) -> bool

pub const fn is_task_not_found(&self) -> bool

pub const fn is_timeout(&self) -> bool

pub const fn is_recursion_limit(&self) -> bool

pub fn cancelled() -> Self

Execution was cancelled

pub const fn is_cancelled(&self) -> bool

Check if this is a cancellation error

pub fn multiple_writers(field_index: usize, writers: Vec<String>) -> Self

Multiple writers on a replace channel

pub const fn is_multiple_writers(&self) -> bool

Check if this is a multiple writers error

pub fn task_panicked(msg: impl Into<String>) -> Self

Task panicked during execution

pub const fn is_task_panicked(&self) -> bool

Check if this is a task panic error

pub fn node_timeout(err: NodeTimeoutError) -> Self

Node execution exceeded its timeout

pub const fn is_node_timeout(&self) -> bool

Check if this is a node timeout error

pub fn parent_command(target: impl Into<String>) -> Self

Subgraph-to-parent routing command

Used by nodes inside a subgraph to request routing to a specific node in the parent graph. The subgraph node returns this error as an exception mechanism, which the SubgraphNode wrapper catches and converts to a Command::goto(target).

Arguments
  • target - Name of the target node in the parent graph
pub const fn is_parent_command(&self) -> bool

Check if this is a parent command routing signal

Returns true when a subgraph node has requested routing to a node in the parent graph.

pub fn parent_command_target(&self) -> Option<&str>

Get the target node name for a parent command

Returns Some(target) when this is a parent command error, containing the name of the target node in the parent graph. Returns None for all other error types.

pub const fn error_code(&self) -> ErrorCode

Get the error code categorizing this error (alias for code())

This method is an alias for code() and exists for compatibility with external code that expects this name.

pub const fn is_graph_recursion_limit(&self) -> bool

Check if this is a graph recursion limit error (alias for is_recursion_limit())

This method is an alias for is_recursion_limit() and exists for compatibility with external code that expects this name.

pub const fn is_invalid_concurrent_update(&self) -> bool

Check if this is an invalid concurrent update error (alias for is_multiple_writers())

This method is an alias for is_multiple_writers() and exists for compatibility with external code that expects this name.

pub const fn is_node_failed(&self) -> bool

Check if this is a node execution failed error

Returns true if this error represents a node execution failure.

pub const fn is_budget_exceeded(&self) -> bool

Check if this is a budget exceeded error

Returns true if this error represents a budget/tokens limit exceeded.

pub const fn is_serialize(&self) -> bool

Check if this is a serialization error

Returns true if this error represents a serialization/deserialization failure.