Module node

Module node 

Node system for graph execution

This module provides the Node trait and conversion utilities for creating nodes from async functions. Nodes are the basic unit of execution in a Juncture graph.

Structs

NodeError
Error information for node execution failures
NodeFnCommand
Wrapper for async functions returning Result<Command<S>, JunctureError>
NodeFnCommandWithConfig
Wrapper for async functions taking RunnableConfig and returning Result<Command<S>, JunctureError>
NodeFnCommandWithConfigAndRuntime
Wrapper for async functions taking (S, RunnableConfig, Runtime<C>) and returning Result<Command<S>, JunctureError>
NodeFnCommandWithRuntime
Wrapper for async functions taking Runtime<C> and returning Result<Command<S>, JunctureError>
NodeFnUpdate
Wrapper for async functions returning Result<S::Update, JunctureError>
NodeFnUpdateWithConfig
Wrapper for async functions taking RunnableConfig and returning Result<S::Update, JunctureError>
NodeFnUpdateWithConfigAndRuntime
Wrapper for async functions taking (S, RunnableConfig, Runtime<C>) and returning Result<S::Update, JunctureError>
NodeFnUpdateWithRuntime
Wrapper for async functions taking Runtime<C> and returning Result<S::Update, JunctureError>

Traits

IntoNode
Conversion trait for creating nodes from async functions
Node
Node trait for graph execution