ExecutionConfig

Struct ExecutionConfig 

pub struct ExecutionConfig {
    pub recursion_limit: usize,
    pub interrupt_before: HashSet<String>,
    pub interrupt_after: HashSet<String>,
    pub budget: Option<BudgetConfig>,
    pub durability: Durability,
    pub retry_policies: HashMap<String, RetryPolicy>,
    pub timeout_policies: HashMap<String, TimeoutPolicy>,
}
Immutable execution configuration

Holds the runtime parameters that do not change during execution, including recursion limits, interrupt settings, and per-node policies.

Fields

recursion_limit: usize

Maximum superstep count

interrupt_before: HashSet<String>

Nodes to interrupt before execution

interrupt_after: HashSet<String>

Nodes to interrupt after execution

budget: Option<BudgetConfig>

Budget configuration

durability: Durability

Checkpoint durability mode

retry_policies: HashMap<String, RetryPolicy>

Per-node retry policies

timeout_policies: HashMap<String, TimeoutPolicy>

Per-node timeout policies

Implementations

Source

impl ExecutionConfig

pub fn new() -> Self

Create a new execution config with defaults

pub const fn with_recursion_limit(self, limit: usize) -> Self

Set the recursion limit

pub fn with_interrupt_before(self, nodes: HashSet<String>) -> Self

Set interrupt_before nodes

pub fn with_interrupt_after(self, nodes: HashSet<String>) -> Self

Set interrupt_after nodes

pub fn with_budget(self, budget: BudgetConfig) -> Self

Set budget configuration

pub const fn with_durability(self, durability: Durability) -> Self

Set durability mode