pub struct SuperstepResult<S: State> {
pub task_outputs: Vec<TaskOutput<S>>,
pub bubble_ups: Vec<BubbleUp<S>>,
}Expand description
Result of executing one superstep
Contains the outputs from all tasks executed in a single superstep,
as well as any subgraph propagation events that need to be handled
by the parent PregelLoop.
Fields
task_outputs: Vec<TaskOutput<S>>Outputs from each completed task
bubble_ups: Vec<BubbleUp<S>>Subgraph propagation events (interrupts, drains, parent commands) that bubble up from nested subgraph execution.
Implementations
Sourceimpl<S: State> SuperstepResult<S>
impl<S: State> SuperstepResult<S>
Sourcepub const fn has_bubble_ups(&self) -> bool
pub const fn has_bubble_ups(&self) -> bool
Check if there are any bubble-up events from subgraph execution