StreamWriterTrait

Trait StreamWriterTrait 

pub trait StreamWriterTrait:
    Send
    + Sync
    + 'static {
    // Required method
    fn emit_custom(&self, node: &str, data: Value);
}
Non-generic stream writer trait for Runtime integration.

StreamWriter<S> is parameterized over the state type S which prevents it from being stored directly in Runtime<C>. This trait provides type-erased access so nodes can emit custom stream events through the runtime regardless of the state type.

Required Methods

fn emit_custom(&self, node: &str, data: Value)

Emit a custom stream data payload.