StreamTransformer

Trait StreamTransformer 

pub trait StreamTransformer:
    Send
    + Sync
    + 'static {
    // Required method
    fn transform(&self, data: Value) -> Option<Value>;
}
Transformer for stream data

Required Methods

fn transform(&self, data: Value) -> Option<Value>

Transform the data.

Returns Some(value) with the transformed result, or None if the data was buffered and should not be emitted yet (e.g. when using BatchTransformer which accumulates to a threshold).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors