pub struct RetryingNode<S: State> { /* private fields */ }Expand description
Node wrapper that adds retry behavior
Wraps an inner node and retries execution according to the provided retry policy when the inner node fails.
Implementations
Sourceimpl<S: State> RetryingNode<S>
impl<S: State> RetryingNode<S>