pub struct InterruptContext { /* private fields */ }Expand description
Interrupt context for managing human-in-the-flow interactions
The context tracks interrupt state across node executions, enabling resumption with human-provided values.
Examples
ⓘ
use juncture_core::interrupt::InterruptContext;
use serde_json::json;
let mut context = InterruptContext::new(
vec![Some(json!("human_input"))],
tokio::sync::mpsc::unbounded_channel(),
);
// Get next interrupt index (increments counter)
let index = context.next_index();Implementations
Sourceimpl InterruptContext
impl InterruptContext
Sourcepub fn new(
resume_values: Vec<Option<Value>>,
interrupt_tx: UnboundedSender<InterruptSignal>,
) -> Self
pub fn new( resume_values: Vec<Option<Value>>, interrupt_tx: UnboundedSender<InterruptSignal>, ) -> Self
Create a new interrupt context
Arguments
resume_values- Values to resume interrupts with (indexed by position)interrupt_tx- Channel for sending interrupt signals
Sourcepub fn next_index(&self) -> usize
pub fn next_index(&self) -> usize
Get the next interrupt index (atomically increments counter)
Sourcepub fn get_resume_value(&self, index: usize) -> Option<Value>
pub fn get_resume_value(&self, index: usize) -> Option<Value>
Get resume value for a given index
Returns None if no resume value exists for this index.
Sourcepub fn current_index(&self) -> usize
pub fn current_index(&self) -> usize
Get the current index without incrementing
Sourcepub fn send_interrupt(
&self,
signal: InterruptSignal,
) -> Result<(), SendError<InterruptSignal>>
pub fn send_interrupt( &self, signal: InterruptSignal, ) -> Result<(), SendError<InterruptSignal>>