Node system for graph execution
This module provides the Node trait and conversion utilities for creating
nodes from async functions. Nodes are the basic unit of execution in a Juncture graph.
Structs
- Node
Error - Error information for node execution failures
- Node
FnCommand - Wrapper for async functions returning
Result<Command<S>, JunctureError> - Node
FnCommand With Config - Wrapper for async functions taking
RunnableConfigand returningResult<Command<S>, JunctureError> - Node
FnCommand With Config AndRuntime - Wrapper for async functions taking
(S, RunnableConfig, Runtime<C>)and returningResult<Command<S>, JunctureError> - Node
FnCommand With Runtime - Wrapper for async functions taking
Runtime<C>and returningResult<Command<S>, JunctureError> - Node
FnUpdate - Wrapper for async functions returning
Result<S::Update, JunctureError> - Node
FnUpdate With Config - Wrapper for async functions taking
RunnableConfigand returningResult<S::Update, JunctureError> - Node
FnUpdate With Config AndRuntime - Wrapper for async functions taking
(S, RunnableConfig, Runtime<C>)and returningResult<S::Update, JunctureError> - Node
FnUpdate With Runtime - Wrapper for async functions taking
Runtime<C>and returningResult<S::Update, JunctureError>